# 支持我们

我们是开源免费项目，AstrBot 的持续开发和维护离不开社区的支持。如果你觉得这个项目对你有帮助，欢迎通过以下几种方式支持我们：

1. 在 GitHub 上给 [AstrBot](https://github.com/AstrBotDevs/AstrBot) 点一个 Star ⭐️。
2. 通过 [爱发电平台](https://afdian.com/a/astrbot_team) 支持我们。
3. 通过这个链接「[雨云官网](https://www.rainyun.com/NjU1ODg0_)」购买云服务器或云应用部署 AstrBot。如果你正好需要云服务器（例如用于部署 AstrBot），非常推荐使用雨云的一键部署方案。雨云是具有自主知识产权的国产云计算服务提供商，拥有可靠的营业资质和实体办公场所。
4. 如果您是企业用户，可以联系我们获取定制化、文档/项目首页赞助广告位等服务支持。

如果你愿意支持我们，那我会非常非常感谢你，也会继续用更优秀的产品回应你的信任。🌟

## Wakatime

AstrBot 主仓库：[![wakatime](https://wakatime.com/badge/user/915e5316-99c6-4563-a483-ef186cf000c9/project/018e705a-a1a7-409a-a849-3013485e6c8e.svg)](https://wakatime.com/badge/user/915e5316-99c6-4563-a483-ef186cf000c9/project/018e705a-a1a7-409a-a849-3013485e6c8e)

AstrBot DashBoard：[![wakatime](https://wakatime.com/badge/user/915e5316-99c6-4563-a483-ef186cf000c9/project/018c440f-c177-45f8-8224-292cdf5926f3.svg)](https://wakatime.com/badge/user/915e5316-99c6-4563-a483-ef186cf000c9/project/018c440f-c177-45f8-8224-292cdf5926f3)

AstrBot 文档：[![wakatime](https://wakatime.com/badge/user/915e5316-99c6-4563-a483-ef186cf000c9/project/018c9619-e195-4b94-bd7b-2ca61679145b.svg)](https://wakatime.com/badge/user/915e5316-99c6-4563-a483-ef186cf000c9/project/018c9619-e195-4b94-bd7b-2ca61679145b)

❤️ 非常欢迎您提交贡献到这个项目中，比如提交 Issue、PR。

## 正文

当你看到这里，说明已经成功部署好消息平台并且实现了第一条指令的收发。接下来，你可以配置大语言模型，或者添加插件。请参看 `配置-接入大模型服务` 一节。
